PRO DUMPAR, mstruc, datstruc
;
;	subroutine to list all the parameters to FOR004.dat
;
;	ipmin,ipmax,ivtic   for  display
;	ihmin,ihmax,ihtic   for display
;	baseline constant
;	type of continuum   g gaussians  p polynomial   n none  s straight line
;       p0,p1,p2  for continuum
;	number of bands
;	center in nm   fwhm in inverse cm    intensity
;	center in nm   fwhm in inverse cm    intensity
;	center in nm   fwhm in inverse cm    intensity
;	etc
;
;
	COMMON FIT$COM, nparus, g

	outfile1 = 'for004.dat'

	openw, lun, outfile1, /get_lun

	idate = SYSTIME()

	PRINTF, lun, idate, $
	       FORMAT="(//1X,A,8X,'=====  MGM-Fit Parameters  =====')"
;
;	now dump out the current parameters
;
;
;	baseline continuum list	
;	
	CASE mstruc.contyp OF 
	'N': PRINTF, lun, ' No Continuum'
	'P': PRINTF, lun, ' Polynomial Continuum in Wavelength Space '
	'Q': PRINTF, lun, ' Polynomial Continuum in Wavenumber Space '
	'G': PRINTF, lun, ' Gaussian Continuum '
	'S': PRINTF, lun, mstruc.swav1, mstruc.swav2, $
		        FORMAT="(' Straight line removed in Wavelength ',2F7.1)"
	'T': PRINTF, lun, mstruc.swav1, mstruc.swav2, $
		        FORAMT="(' Straight line removed in Wavenumber ',2F7.1)"
	ELSE:
	ENDCASE
;
;	now list bands
;
	PRINTF, lun, mstruc.nbands, $
		FORMAT="(//,2X,I4,' Absorption Bands'/)"
 
	OFORM = "(2x,'#',8x,'Center',13x,'FWHM',12x"
	OFORM2 = ",'Strength',10x,'Log Area'/)"
	OFORM = OFORM + OFORM2
  
	PRINTF, lun, FORMAT=oform

	gsum = TOTAL( datstruc.gauss, 1 )

	FOR k=0,mstruc.nbands-1 DO $
	    PRINTF, lun, k+1, mstruc.gcent(k), mstruc.gfwhm(k), $
		mstruc.gstr(k), gsum(k), $
		FORMAT="(I3,3x,E15.8,3x,E15.8,3x,E16.8,3x,E16.8)"
;
;	write error
;
	rmscur = RMSERR( datstruc.FIT, datstruc.RATIO )

	PRINTF, lun, $
	        rmscur, $
	    	FORMAT="(/' Current RMS Error ',E12.6)"

	rmscur = SQRT( ( rmscur^2 )*datstruc.npnts / $
		       ( datstruc.npnts-(mstruc.nparam-4) ) )

	CLOSE, lun
	FREE_LUN, lun

;
;	write out for009 with 2 sigma range of parameters
;

	outfile2 = 'for009.dat'

	openw, lun2, outfile2, /get_lun
	PRINTF, lun2, '     MGM_Ver 2 --- 2 Sigma (95 perc. confidence)', $
	        ' Model Parameters'
;
;	baseline continuum list	
;	
    inparam = mstruc.nparam
	IF ( mstruc.contyp NE 'N') THEN BEGIN
	   ndx = WHERE( mstruc.cparam NE 0., ncpar )
	   clow  = mstruc.cparam(ndx) - mstruc.std( inparam-ncpar:inparam-1 )
	   chigh = mstruc.cparam(ndx) + mstruc.std( inparam-ncpar:inparam-1 )

	   FOR i=0,ncpar-1 DO BEGIN
	       cform = "(/2x,E12.2,' <P" + STRTRIM(i,2)+ "< ',E12.2)"
	       PRINTF, lun2, $
		       clow(i), $
		       chigh(i), $
	     	       FORMAT=cform
	   ENDFOR
	   uncert = mstruc.std( inparam-ncpar:inparam-1 )
       IF ncpar LT 4 THEN $
	      uncert = [uncert, FLTARR( 4-ncpar )]
    ENDIF
	PRINTF, lun2, ''
;
;	now list bands...
;
; 	convert stnd error wn to wlength
;
	cntmax=1.0/(1.0/mstruc.gcent-mstruc.std(0:mstruc.nbands-1)*1E-7)
	cntmin=1.0/(1.0/mstruc.gcent+mstruc.std(0:mstruc.nbands-1)*1E-7)

	gform1 = "(I3,f10.3,' <c<',f10.3,2x,f10.3,' <w<',f10.3"
	gform2 = ",1x,f12.3,' <s<',f10.3)"
	gform = gform1 + gform2

	FOR k=0,mstruc.nbands-1 DO BEGIN
	   PRINTF, lun2, $
		   k+1, $
		   cntmin(k), $
		   cntmax(k), $
		   (mstruc.gfwhm(k)-mstruc.std(mstruc.nbands+k)), $
		   (mstruc.std(mstruc.nbands+k)+mstruc.gfwhm(k)), $
		   (mstruc.gstr(k)-mstruc.std(2*mstruc.nbands+k)), $
		   (mstruc.std(2*mstruc.nbands+k)+mstruc.gstr(k)), $
		   FORMAT = gform 

	ENDFOR
	CLOSE, lun2
	FREE_LUN, lun2

RETURN
END
